@@ -1,2 +1,2 @@
-from .client import Client
+from .client import AsyncClient, Client
 from .errors import APIErrorCode, APIResponseError
